@@ -219,6 +219,20 @@ class MetadataSchemaListModel(_ConfigFileVariableBaseModel):
         value = os.path.abspath(metadata_schema_directory)
         self._put(value)
 
+    def put_metadata_schema_item(self, name, metadata_schema):
+        """Put/update a metadata schema item in the metadata schema directory.
+
+        :param name: name of the metadata schema
+        :param metadata_schema: dictionary with the metadata schema
+        """
+        fname = name + ".json"
+        fpath = os.path.join(
+            self.get_metadata_schema_directory(),
+            fname
+        )
+        with open(fpath, "w") as fh:
+            json.dump(metadata_schema, fh)
+
     @property
     def metadata_model_names(self):
         """Return list of metadata model names.
@@ -813,10 +827,10 @@ class ProtoDataSetModel(object):
             ds_creator.put_readme("\n".join(readme_lines))
 
             # Add the metadata schema.
-            metdata_schema = self.metadata_model.get_master_schema()
+            metadata_schema = self.metadata_model.get_master_schema()
             ds_creator.put_annotation(
                 METADATA_SCHEMA_ANNOTATION_NAME,
-                metdata_schema
+                metadata_schema
             )
 
             # Add data items.
